summaryrefslogtreecommitdiffstats
path: root/kverbos/kverbos/kverbosdoc.h
diff options
context:
space:
mode:
Diffstat (limited to 'kverbos/kverbos/kverbosdoc.h')
-rw-r--r--kverbos/kverbos/kverbosdoc.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/kverbos/kverbos/kverbosdoc.h b/kverbos/kverbos/kverbosdoc.h
index efe5d98c..b419c300 100644
--- a/kverbos/kverbos/kverbosdoc.h
+++ b/kverbos/kverbos/kverbosdoc.h
@@ -58,14 +58,15 @@ class KVerbosUser;
* @author Source Framework Automatically Generated by KDevelop, (c) The KDevelop Team.
* @version KDevelop version 1.2 code generation
*/
-class KVerbosDoc : public QObject
+class KVerbosDoc : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor for the fileclass of the application
*/
- KVerbosDoc(TQWidget *parent, const char *name=0);
+ KVerbosDoc(TQWidget *tqparent, const char *name=0);
/**
* Destructor for the fileclass of the application
*/
@@ -113,10 +114,10 @@ class KVerbosDoc : public QObject
const KURL& URL() const;
/** sets the URL of the document */
void setURL(const KURL& url);
/** es wird ein Verb der Liste hinzugefügt, ist emitStatus = true, wird auch
* die Statuszeile entsprechend angepasst.
*/
- void appendVerb(const verbSpanish v, bool emitStatus = true);
+ void appendVerb(const verbSpanish v, bool emittqStatus = true);
/** prüft, ob die Liste des Dokumentes leer ist */
bool isEmpty() const;
/** Gibt einen Zeiger auf die Verbliste des Dokumentes zurück */
@@ -140,8 +141,8 @@ class KVerbosDoc : public QObject
public slots:
/**
- * calls repaint() on all views connected to the document object and is called by the view by which the document has been changed.
- * As this view normally repaints itself, it is excluded from the paintEvent.
+ * calls tqrepaint() on all views connected to the document object and is called by the view by which the document has been changed.
+ * As this view normally tqrepaints itself, it is excluded from the paintEvent.
*/
void slotUpdateAllViews(KVerbosView *sender);
@@ -113,10 +114,10 @@ class KVerbosDoc : public QObject
/** sets the URL of the document */
void setURL(const KURL& url);
- /** es wird ein Verb der Liste hinzugefügt, ist emitStatus = true, wird auch
+ /** es wird ein Verb der Liste hinzugefügt, ist emittqStatus = true, wird auch
* die Statuszeile entsprechend angepasst.
*/